#toolbar-inplace-edit {
    background: #dddddd;
    border: 1px solid #cccccc;
    font-size: 11px;
    font-family: sans-serif;
    position:fixed;
    top: 0px;
    z-index: 99999999;
    width: 100%;
}


#toolbar-inplace-edit div.toolbarContainer {
    display: inline;
    line-height: 20px;
    border-right: 1px solid #cccccc;
}

#toolbar-inplace-edit .toolbarAction {
    cursor: pointer;
    padding: 0px 5px;
}

#toolbar-inplace-edit .active {
    background-color: #bfbfbf;
}
